<?php

namespace Btravel\Cards\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Cards\Models\BtCardCard;

class BtCardCardPolicy
{

    /**
     * Determine if the given user can view the bt_card_card.
     *
     * @param UserPolicy $user
     * @param BtCardCard $bt_card_card
     *
     * @return bool
     */
    public function view(UserPolicy $user, BtCardCard $bt_card_card)
    {
        if ($user->canDo('cards.bt_card_card.view') && $user->isAdmin()) {
            return true;
        }

        return $bt_card_card->user_id == user_id() && $bt_card_card->user_type == user_type();
    }

    /**
     * Determine if the given user can create a bt_card_card.
     *
     * @param UserPolicy $user
     * @param BtCardCard $bt_card_card
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('cards.bt_card_card.create');
    }

    /**
     * Determine if the given user can update the given bt_card_card.
     *
     * @param UserPolicy $user
     * @param BtCardCard $bt_card_card
     *
     * @return bool
     */
    public function update(UserPolicy $user, BtCardCard $bt_card_card)
    {
        if ($user->canDo('cards.bt_card_card.edit') && $user->isAdmin()) {
            return true;
        }

        return $bt_card_card->user_id == user_id() && $bt_card_card->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given bt_card_card.
     *
     * @param UserPolicy $user
     * @param BtCardCard $bt_card_card
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BtCardCard $bt_card_card)
    {
        return $bt_card_card->user_id == user_id() && $bt_card_card->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given bt_card_card.
     *
     * @param UserPolicy $user
     * @param BtCardCard $bt_card_card
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BtCardCard $bt_card_card)
    {
        if ($user->canDo('cards.bt_card_card.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bt_card_card.
     *
     * @param UserPolicy $user
     * @param BtCardCard $bt_card_card
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BtCardCard $bt_card_card)
    {
        if ($user->canDo('cards.bt_card_card.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
