<?php

namespace Btravel\Card\Providers;

use Illuminate\Support\ServiceProvider;

class CardServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'card');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'card');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerCard();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerCard()
    {
        $this->app->bind('card', function($app) {
            return new Card($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Card', 'Lavalite\Card\Facades\Card');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('btravel.card', function ($app) {
            return $this->app->make('Btravel\Card\Card');
        });

        // Bind Card to repository
        $this->app->bind(
            'Btravel\Card\Interfaces\CardRepositoryInterface',
            \Btravel\Card\Repositories\Eloquent\CardRepository::class
        );        // Bind Offer to repository
        $this->app->bind(
            'Btravel\Card\Interfaces\OfferRepositoryInterface',
            \Btravel\Card\Repositories\Eloquent\OfferRepository::class
        );        // Bind BtCardCard to repository
        $this->app->bind(
            'Btravel\Card\Interfaces\BtCardCardRepositoryInterface',
            \Btravel\Card\Repositories\Eloquent\BtCardCardRepository::class
        );        // Bind Brand to repository
        $this->app->bind(
            'Btravel\Card\Interfaces\BrandRepositoryInterface',
            \Btravel\Card\Repositories\Eloquent\BrandRepository::class
        );

        $this->app->register(\Btravel\Card\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Btravel\Card\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and card's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'btravel.card'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeCard::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['btravel.card'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('btravel/card.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/card')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/card')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
