<?php

namespace Btravel\Cards\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Btravel\Cards\Models\Cards;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Btravel\Cards\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/cards/card/*')) {
            Route::bind('card', function ($card) {
                $cardrepo = $this->app->make('Btravel\Cards\Interfaces\CardRepositoryInterface');
                return $cardrepo->findorNew($card);
            });
        }

        if (Request::is('*/cards/offer/*')) {
            Route::bind('offer', function ($offer) {
                $offerrepo = $this->app->make('Btravel\Cards\Interfaces\OfferRepositoryInterface');
                return $offerrepo->findorNew($offer);
            });
        }

        if (Request::is('*/cards/bt_card_card/*')) {
            Route::bind('bt_card_card', function ($bt_card_card) {
                $bt_card_cardrepo = $this->app->make('Btravel\Cards\Interfaces\BtCardCardRepositoryInterface');
                return $bt_card_cardrepo->findorNew($bt_card_card);
            });
        }

        if (Request::is('*/cards/brand/*')) {
            Route::bind('brand', function ($brand) {
                $brandrepo = $this->app->make('Btravel\Cards\Interfaces\BrandRepositoryInterface');
                return $brandrepo->findorNew($brand);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
